@@ -29,10 +29,9 @@ class Interactions(Navigator):
         
         # Check User Vadility
         try:
-            result = self._is_valid_user(user, nav_to_user=False)
+            result = self._is_valid_user(user)
             LOGGER.debug('INSTACLIENT: User <{}> is valid'.format(user))
             private = False
-            
         # User is private
         except PrivateAccountError:
             private = True
@@ -64,15 +63,17 @@ class Interactions(Navigator):
         Raises:
             InvalidUserError: raised if the user specified by the `user` argument is invalid.
         """
-        if nav_to_user:
-            self._nav_user(user, check_user)
-        elif check_user:
+        
+        if check_user:
             try:
-                self._is_valid_user(user, nav_to_user=False)
+                self._is_valid_user(user)
             except PrivateAccountError:
                 pass
             LOGGER.debug('INSTACLIENT: User <{}> is valid'.format(user))
 
+        if nav_to_user:
+            self._nav_user(user, check_user)
+
         if self._check_existence(EC.presence_of_element_located((By.XPATH, Paths.UNFOLLOW_BTN))):
             unfollow_btn = self._find_element(EC.presence_of_element_located((By.XPATH, Paths.UNFOLLOW_BTN)))
             self._press_button(unfollow_btn)
@@ -184,7 +185,7 @@ class Interactions(Navigator):
     def _like_post(self, shortcode:str):
         # Nav Post Page
         self._nav_post(shortcode)
-        
+
         try:
             like_btn = self._find_element(EC.presence_of_element_located((By.XPATH, Paths.LIKE_BTN)))
             self._press_button(like_btn)
